from mag_tools.model.base_enum import BaseEnum


class TestComponentType(BaseEnum):
    """
    测试组件类型枚举
    枚举值为测试组件的名称，如：TestComponentType.TEST_PLAN
    """
    PLAN = ('Plan', '测试计划')  # 测试计划
    MODULE = ('Module', '测试功能模块')  # 测试功能模块
    CASE = ('Case', '测试用例')  # 测试用例
    FUNCTION = ('Function', '测试功能')  # 测试功能
    STEP = ('Step', '测试步骤')  # 测试步骤



import os

import psutil
import threading

class WinAppUtils:
    @staticmethod
    def check_port_used(port: int):
        # 注意：psutil.net_connections() 返回的是所有当前的网络连接信息
        # 我们需要遍历这些信息来找到指定端口的连接
        for conn in psutil.net_connections(kind='inet'):
            if conn.laddr.port == port:
                return True  # 端口已被占用
        return False  # 端口未被占用

    @staticmethod
    def run_bat_file_in_thread(bat_file_path):
        # 在新线程中执行 .bat 文件
        os.system(bat_file_path)

    @staticmethod
    def start_win_app_driver(app_win_driver_path: str, port: int):
        if WinAppUtils.check_port_used(port):
            print(f"WinAppDriver程序 {port} 已启动")
        else:
            print(f"WinAppDriver程序 {port} 未启动，启动WinAppDriver")
            thread = threading.Thread(target=WinAppUtils.run_bat_file_in_thread, args=(app_win_driver_path,))
            thread.start()



from typing import Optional, Union

from mag_tools.model.base_enum import BaseEnum

from mag_test.model.control_type import ControlType


class ActionType(BaseEnum):
    CLICK = ("click", "单击")   # 按钮、菜单、ITEM等控件的缺省操作
    DOUBLE_CLICK = ("double_click", "双击")
    RIGHT_CLICK = ("right_click", "右键单击")
    CLEAR = ("clear", "清除")
    SUBMIT = ("submit", "提交")
    SEND_KEYS = ("send_keys", "发送按键")
    # 以下为虚拟或组合的控件事件
    SET_TEXT = ("set_text", "设置文件")  # 文本框、文档等可编辑控件的缺省操作，相当于 CLEAR和SEND_KEYS
    SELECT = ("select", "选择")   #  # 应用于可选择控件
    CLEAR_DIR = ("clear_dir", "清除目录") # 应用于目录操作
    DELETE_DIR = ("delete_dir", "删除目录")  # 应用于目录操作
    DELETE_FILE = ("delete_file", "删除文件") # 应用于文件操作
    MENU_ITEM = ("menu_item", "点击菜单项") # 为缺省操作

    @classmethod
    def of_code(cls, code: Optional[Union[str or int]]):
        """
        判定是否为菜单项，当菜单项名不为空且对应类型为None时，则缺省为菜单项
        :param code: 菜单项名
        """
        _type = super().of_code(code)
        if _type is None:
            _type = cls.MENU_ITEM
        return _type

    @classmethod
    def default_action(cls, control_type:Optional[ControlType]):
        _default_action = cls.CLICK
        if control_type in {ControlType.EDIT, ControlType.DOC, ControlType.COMBO_BOX}:
            _default_action = cls.SET_TEXT

        return _default_action

if __name__ == '__main__':
    print(ActionType.of_code('aaa'))
